# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import info_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2


class ResourceInfoServiceStub(object):
    """ResourceInfoService

    This is a generic service that contains utility functions 
    these functions are used to query additional meta-information
    about resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetResourceHierarchy = channel.unary_unary(
                '/aruna.api.storage.services.v1.ResourceInfoService/GetResourceHierarchy',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetResourceHierarchyRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetResourceHierarchyResponse.FromString,
                )


class ResourceInfoServiceServicer(object):
    """ResourceInfoService

    This is a generic service that contains utility functions 
    these functions are used to query additional meta-information
    about resources
    """

    def GetResourceHierarchy(self, request, context):
        """GetResourceHierarchy

        This requests a hierarchy based on one resource (object / objectgroup or collection)
        and returns a hierarchy with all associated higherlevel objects up to projects.
        Needs projects level read access.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResourceInfoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetResourceHierarchy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResourceHierarchy,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetResourceHierarchyRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetResourceHierarchyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.ResourceInfoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ResourceInfoService(object):
    """ResourceInfoService

    This is a generic service that contains utility functions 
    these functions are used to query additional meta-information
    about resources
    """

    @staticmethod
    def GetResourceHierarchy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ResourceInfoService/GetResourceHierarchy',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetResourceHierarchyRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetResourceHierarchyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class StorageInfoServiceStub(object):
    """StorageInfoService

    This is a generic service that contains utility functions 
    these functions are used to query additional meta-information
    about the status of the overall storage architecture
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStorageVersion = channel.unary_unary(
                '/aruna.api.storage.services.v1.StorageInfoService/GetStorageVersion',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageVersionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageVersionResponse.FromString,
                )
        self.GetStorageStatus = channel.unary_unary(
                '/aruna.api.storage.services.v1.StorageInfoService/GetStorageStatus',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageStatusRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageStatusResponse.FromString,
                )


class StorageInfoServiceServicer(object):
    """StorageInfoService

    This is a generic service that contains utility functions 
    these functions are used to query additional meta-information
    about the status of the overall storage architecture
    """

    def GetStorageVersion(self, request, context):
        """GetStorageVersion

        Status: ALPHA

        A request to get the current version of the server application
        String representation and https://semver.org/
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStorageStatus(self, request, context):
        """GetStorageStatus

        Status: ALPHA

        A request to get the current status of the storage components by location(s)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StorageInfoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStorageVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStorageVersion,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageVersionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageVersionResponse.SerializeToString,
            ),
            'GetStorageStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStorageStatus,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageStatusRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.StorageInfoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StorageInfoService(object):
    """StorageInfoService

    This is a generic service that contains utility functions 
    these functions are used to query additional meta-information
    about the status of the overall storage architecture
    """

    @staticmethod
    def GetStorageVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.StorageInfoService/GetStorageVersion',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageVersionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStorageStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.StorageInfoService/GetStorageStatus',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageStatusRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_info__service__pb2.GetStorageStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from aruna.api.storage.models.v1 import query_pb2 as _query_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateNewCollectionRequest(_message.Message):
    __slots__ = ["dataclass", "description", "hooks", "label_ontology", "labels", "name", "project_id"]
    DATACLASS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LABEL_ONTOLOGY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    dataclass: _models_pb2.DataClass
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    label_ontology: _models_pb2.LabelOntology
    labels: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    name: str
    project_id: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., project_id: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., label_ontology: _Optional[_Union[_models_pb2.LabelOntology, _Mapping]] = ..., dataclass: _Optional[_Union[_models_pb2.DataClass, str]] = ...) -> None: ...

class CreateNewCollectionResponse(_message.Message):
    __slots__ = ["collection_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    def __init__(self, collection_id: _Optional[str] = ...) -> None: ...

class DeleteCollectionRequest(_message.Message):
    __slots__ = ["collection_id", "force"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    force: bool
    def __init__(self, collection_id: _Optional[str] = ..., force: bool = ...) -> None: ...

class DeleteCollectionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetCollectionByIDRequest(_message.Message):
    __slots__ = ["collection_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    def __init__(self, collection_id: _Optional[str] = ...) -> None: ...

class GetCollectionByIDResponse(_message.Message):
    __slots__ = ["collection"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    collection: _models_pb2.CollectionOverview
    def __init__(self, collection: _Optional[_Union[_models_pb2.CollectionOverview, _Mapping]] = ...) -> None: ...

class GetCollectionsRequest(_message.Message):
    __slots__ = ["label_or_id_filter", "page_request", "project_id"]
    LABEL_OR_ID_FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    label_or_id_filter: _query_pb2.LabelOrIDQuery
    page_request: _query_pb2.PageRequest
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., label_or_id_filter: _Optional[_Union[_query_pb2.LabelOrIDQuery, _Mapping]] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class GetCollectionsResponse(_message.Message):
    __slots__ = ["collections"]
    COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    collections: _models_pb2.CollectionOverviews
    def __init__(self, collections: _Optional[_Union[_models_pb2.CollectionOverviews, _Mapping]] = ...) -> None: ...

class PinCollectionVersionRequest(_message.Message):
    __slots__ = ["collection_id", "version"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    version: _models_pb2.Version
    def __init__(self, collection_id: _Optional[str] = ..., version: _Optional[_Union[_models_pb2.Version, _Mapping]] = ...) -> None: ...

class PinCollectionVersionResponse(_message.Message):
    __slots__ = ["collection"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    collection: _models_pb2.CollectionOverview
    def __init__(self, collection: _Optional[_Union[_models_pb2.CollectionOverview, _Mapping]] = ...) -> None: ...

class UpdateCollectionRequest(_message.Message):
    __slots__ = ["collection_id", "dataclass", "description", "hooks", "label_ontology", "labels", "name", "version"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    DATACLASS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LABEL_ONTOLOGY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    dataclass: _models_pb2.DataClass
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    label_ontology: _models_pb2.LabelOntology
    labels: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    name: str
    version: _models_pb2.Version
    def __init__(self, collection_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., label_ontology: _Optional[_Union[_models_pb2.LabelOntology, _Mapping]] = ..., dataclass: _Optional[_Union[_models_pb2.DataClass, str]] = ..., version: _Optional[_Union[_models_pb2.Version, _Mapping]] = ...) -> None: ...

class UpdateCollectionResponse(_message.Message):
    __slots__ = ["collection"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    collection: _models_pb2.CollectionOverview
    def __init__(self, collection: _Optional[_Union[_models_pb2.CollectionOverview, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/service_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import auth_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_auth__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;aruna/api/storage/services/v1/service_account_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a&aruna/api/storage/models/v1/auth.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x99\x01\n\x1b\x43reateServiceAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12G\n\npermission\x18\x03 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\"\xb2\x01\n\x0eServiceAccount\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12G\n\npermission\x18\x04 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\"v\n\x1c\x43reateServiceAccountResponse\x12V\n\x0fservice_account\x18\x01 \x01(\x0b\x32-.aruna.api.storage.services.v1.ServiceAccountR\x0eserviceAccount\"\x85\x02\n CreateServiceAccountTokenRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x39\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12G\n\npermission\x18\x05 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\"\x80\x01\n!CreateServiceAccountTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\x12!\n\x0ctoken_secret\x18\x02 \x01(\tR\x0btokenSecret\"\x9b\x01\n#EditServiceAccountPermissionRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12N\n\x0enew_permission\x18\x02 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\rnewPermission\"~\n$EditServiceAccountPermissionResponse\x12V\n\x0fservice_account\x18\x01 \x01(\x0b\x32-.aruna.api.storage.services.v1.ServiceAccountR\x0eserviceAccount\"`\n\x1dGetServiceAccountTokenRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12\x19\n\x08token_id\x18\x02 \x01(\tR\x07tokenId\"Z\n\x1eGetServiceAccountTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\"F\n\x1eGetServiceAccountTokensRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\"[\n\x1fGetServiceAccountTokensResponse\x12\x38\n\x05token\x18\x01 \x03(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\"C\n\"GetServiceAccountsByProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"w\n#GetServiceAccountsByProjectResponse\x12P\n\x0csvc_accounts\x18\x01 \x03(\x0b\x32-.aruna.api.storage.services.v1.ServiceAccountR\x0bsvcAccounts\"c\n DeleteServiceAccountTokenRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12\x19\n\x08token_id\x18\x02 \x01(\tR\x07tokenId\"#\n!DeleteServiceAccountTokenResponse\"I\n!DeleteServiceAccountTokensRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\"$\n\"DeleteServiceAccountTokensResponse\"C\n\x1b\x44\x65leteServiceAccountRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\"\x1e\n\x1c\x44\x65leteServiceAccountResponse2\x95\x0f\n\x15ServiceAccountService\x12\xaf\x01\n\x14\x43reateServiceAccount\x12:.aruna.api.storage.services.v1.CreateServiceAccountRequest\x1a;.aruna.api.storage.services.v1.CreateServiceAccountResponse\"\x1e\x82\xd3\xe4\x93\x02\x18:\x01*\"\x13/v1/service_account\x12\xd5\x01\n\x19\x43reateServiceAccountToken\x12?.aruna.api.storage.services.v1.CreateServiceAccountTokenRequest\x1a@.aruna.api.storage.services.v1.CreateServiceAccountTokenResponse\"5\x82\xd3\xe4\x93\x02/:\x01*\"*/v1/service_account/{svc_account_id}/token\x12\xe4\x01\n\x1c\x45\x64itServiceAccountPermission\x12\x42.aruna.api.storage.services.v1.EditServiceAccountPermissionRequest\x1a\x43.aruna.api.storage.services.v1.EditServiceAccountPermissionResponse\";\x82\xd3\xe4\x93\x02\x35:\x01*\x1a\x30/v1/service_account/{svc_account_id}/permissions\x12\xd4\x01\n\x16GetServiceAccountToken\x12<.aruna.api.storage.services.v1.GetServiceAccountTokenRequest\x1a=.aruna.api.storage.services.v1.GetServiceAccountTokenResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/service_account/{svc_account_id}/token/{token_id}\x12\xcd\x01\n\x17GetServiceAccountTokens\x12=.aruna.api.storage.services.v1.GetServiceAccountTokensRequest\x1a>.aruna.api.storage.services.v1.GetServiceAccountTokensResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/service_account/{svc_account_id}/tokens\x12\xd6\x01\n\x1bGetServiceAccountsByProject\x12\x41.aruna.api.storage.services.v1.GetServiceAccountsByProjectRequest\x1a\x42.aruna.api.storage.services.v1.GetServiceAccountsByProjectResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/service_account/project/{project_id}\x12\xdd\x01\n\x19\x44\x65leteServiceAccountToken\x12?.aruna.api.storage.services.v1.DeleteServiceAccountTokenRequest\x1a@.aruna.api.storage.services.v1.DeleteServiceAccountTokenResponse\"=\x82\xd3\xe4\x93\x02\x37*5/v1/service_account/{svc_account_id}/token/{token_id}\x12\xd6\x01\n\x1a\x44\x65leteServiceAccountTokens\x12@.aruna.api.storage.services.v1.DeleteServiceAccountTokensRequest\x1a\x41.aruna.api.storage.services.v1.DeleteServiceAccountTokensResponse\"3\x82\xd3\xe4\x93\x02-*+/v1/service_account/{svc_account_id}/tokens\x12\xbd\x01\n\x14\x44\x65leteServiceAccount\x12:.aruna.api.storage.services.v1.DeleteServiceAccountRequest\x1a;.aruna.api.storage.services.v1.DeleteServiceAccountResponse\",\x82\xd3\xe4\x93\x02&*$/v1/service_account/{svc_account_id}\x1a\x12\xfa\xd2\xe4\x93\x02\x0c\x12\nUNFINISHEDB\x97\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x15ServiceAccountServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.service_account_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\025ServiceAccountServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _SERVICEACCOUNTSERVICE._options = None
  _SERVICEACCOUNTSERVICE._serialized_options = b'\372\322\344\223\002\014\022\nUNFINISHED'
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccount']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccount']._serialized_options = b'\202\323\344\223\002\030:\001*\"\023/v1/service_account'
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccountToken']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccountToken']._serialized_options = b'\202\323\344\223\002/:\001*\"*/v1/service_account/{svc_account_id}/token'
  _SERVICEACCOUNTSERVICE.methods_by_name['EditServiceAccountPermission']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['EditServiceAccountPermission']._serialized_options = b'\202\323\344\223\0025:\001*\0320/v1/service_account/{svc_account_id}/permissions'
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountToken']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountToken']._serialized_options = b'\202\323\344\223\0027\0225/v1/service_account/{svc_account_id}/token/{token_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountTokens']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountTokens']._serialized_options = b'\202\323\344\223\002-\022+/v1/service_account/{svc_account_id}/tokens'
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountsByProject']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountsByProject']._serialized_options = b'\202\323\344\223\002*\022(/v1/service_account/project/{project_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountToken']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountToken']._serialized_options = b'\202\323\344\223\0027*5/v1/service_account/{svc_account_id}/token/{token_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountTokens']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountTokens']._serialized_options = b'\202\323\344\223\002-*+/v1/service_account/{svc_account_id}/tokens'
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccount']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccount']._serialized_options = b'\202\323\344\223\002&*$/v1/service_account/{svc_account_id}'
  _CREATESERVICEACCOUNTREQUEST._serialized_start=227
  _CREATESERVICEACCOUNTREQUEST._serialized_end=380
  _SERVICEACCOUNT._serialized_start=383
  _SERVICEACCOUNT._serialized_end=561
  _CREATESERVICEACCOUNTRESPONSE._serialized_start=563
  _CREATESERVICEACCOUNTRESPONSE._serialized_end=681
  _CREATESERVICEACCOUNTTOKENREQUEST._serialized_start=684
  _CREATESERVICEACCOUNTTOKENREQUEST._serialized_end=945
  _CREATESERVICEACCOUNTTOKENRESPONSE._serialized_start=948
  _CREATESERVICEACCOUNTTOKENRESPONSE._serialized_end=1076
  _EDITSERVICEACCOUNTPERMISSIONREQUEST._serialized_start=1079
  _EDITSERVICEACCOUNTPERMISSIONREQUEST._serialized_end=1234
  _EDITSERVICEACCOUNTPERMISSIONRESPONSE._serialized_start=1236
  _EDITSERVICEACCOUNTPERMISSIONRESPONSE._serialized_end=1362
  _GETSERVICEACCOUNTTOKENREQUEST._serialized_start=1364
  _GETSERVICEACCOUNTTOKENREQUEST._serialized_end=1460
  _GETSERVICEACCOUNTTOKENRESPONSE._serialized_start=1462
  _GETSERVICEACCOUNTTOKENRESPONSE._serialized_end=1552
  _GETSERVICEACCOUNTTOKENSREQUEST._serialized_start=1554
  _GETSERVICEACCOUNTTOKENSREQUEST._serialized_end=1624
  _GETSERVICEACCOUNTTOKENSRESPONSE._serialized_start=1626
  _GETSERVICEACCOUNTTOKENSRESPONSE._serialized_end=1717
  _GETSERVICEACCOUNTSBYPROJECTREQUEST._serialized_start=1719
  _GETSERVICEACCOUNTSBYPROJECTREQUEST._serialized_end=1786
  _GETSERVICEACCOUNTSBYPROJECTRESPONSE._serialized_start=1788
  _GETSERVICEACCOUNTSBYPROJECTRESPONSE._serialized_end=1907
  _DELETESERVICEACCOUNTTOKENREQUEST._serialized_start=1909
  _DELETESERVICEACCOUNTTOKENREQUEST._serialized_end=2008
  _DELETESERVICEACCOUNTTOKENRESPONSE._serialized_start=2010
  _DELETESERVICEACCOUNTTOKENRESPONSE._serialized_end=2045
  _DELETESERVICEACCOUNTTOKENSREQUEST._serialized_start=2047
  _DELETESERVICEACCOUNTTOKENSREQUEST._serialized_end=2120
  _DELETESERVICEACCOUNTTOKENSRESPONSE._serialized_start=2122
  _DELETESERVICEACCOUNTTOKENSRESPONSE._serialized_end=2158
  _DELETESERVICEACCOUNTREQUEST._serialized_start=2160
  _DELETESERVICEACCOUNTREQUEST._serialized_end=2227
  _DELETESERVICEACCOUNTRESPONSE._serialized_start=2229
  _DELETESERVICEACCOUNTRESPONSE._serialized_end=2259
  _SERVICEACCOUNTSERVICE._serialized_start=2262
  _SERVICEACCOUNTSERVICE._serialized_end=4203
# @@protoc_insertion_point(module_scope)



from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
STATUS_AVAILABLE: Status
STATUS_DEGRADED: Status
STATUS_UNAVAILABLE: Status
STATUS_UNKNOWN: Status
STATUS_UNSPECIFIED: Status

class ComponentStatus(_message.Message):
    __slots__ = ["component_name", "location_status"]
    COMPONENT_NAME_FIELD_NUMBER: _ClassVar[int]
    LOCATION_STATUS_FIELD_NUMBER: _ClassVar[int]
    component_name: str
    location_status: _containers.RepeatedCompositeFieldContainer[LocationStatus]
    def __init__(self, component_name: _Optional[str] = ..., location_status: _Optional[_Iterable[_Union[LocationStatus, _Mapping]]] = ...) -> None: ...

class ComponentVersion(_message.Message):
    __slots__ = ["component_name", "location_version"]
    COMPONENT_NAME_FIELD_NUMBER: _ClassVar[int]
    LOCATION_VERSION_FIELD_NUMBER: _ClassVar[int]
    component_name: str
    location_version: _containers.RepeatedCompositeFieldContainer[LocationVersion]
    def __init__(self, component_name: _Optional[str] = ..., location_version: _Optional[_Iterable[_Union[LocationVersion, _Mapping]]] = ...) -> None: ...

class GetResourceHierarchyRequest(_message.Message):
    __slots__ = ["resource_id", "resource_type"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    resource_type: _models_pb2.ResourceType
    def __init__(self, resource_id: _Optional[str] = ..., resource_type: _Optional[_Union[_models_pb2.ResourceType, str]] = ...) -> None: ...

class GetResourceHierarchyResponse(_message.Message):
    __slots__ = ["hierarchies"]
    HIERARCHIES_FIELD_NUMBER: _ClassVar[int]
    hierarchies: _containers.RepeatedCompositeFieldContainer[Hierarchy]
    def __init__(self, hierarchies: _Optional[_Iterable[_Union[Hierarchy, _Mapping]]] = ...) -> None: ...

class GetStorageStatusRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetStorageStatusResponse(_message.Message):
    __slots__ = ["component_status"]
    COMPONENT_STATUS_FIELD_NUMBER: _ClassVar[int]
    component_status: _containers.RepeatedCompositeFieldContainer[ComponentStatus]
    def __init__(self, component_status: _Optional[_Iterable[_Union[ComponentStatus, _Mapping]]] = ...) -> None: ...

class GetStorageVersionRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetStorageVersionResponse(_message.Message):
    __slots__ = ["component_version"]
    COMPONENT_VERSION_FIELD_NUMBER: _ClassVar[int]
    component_version: _containers.RepeatedCompositeFieldContainer[ComponentVersion]
    def __init__(self, component_version: _Optional[_Iterable[_Union[ComponentVersion, _Mapping]]] = ...) -> None: ...

class Hierarchy(_message.Message):
    __slots__ = ["collection_id", "object_group_ids", "object_id", "project_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_group_ids: _containers.RepeatedScalarFieldContainer[str]
    object_id: str
    project_id: str
    def __init__(self, object_id: _Optional[str] = ..., object_group_ids: _Optional[_Iterable[str]] = ..., collection_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class LocationStatus(_message.Message):
    __slots__ = ["location", "status"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    location: str
    status: Status
    def __init__(self, location: _Optional[str] = ..., status: _Optional[_Union[Status, str]] = ...) -> None: ...

class LocationVersion(_message.Message):
    __slots__ = ["location", "version"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    location: str
    version: SemanticVersion
    def __init__(self, location: _Optional[str] = ..., version: _Optional[_Union[SemanticVersion, _Mapping]] = ...) -> None: ...

class SemanticVersion(_message.Message):
    __slots__ = ["labels", "major", "minor", "patch", "version_string"]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    MAJOR_FIELD_NUMBER: _ClassVar[int]
    MINOR_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    VERSION_STRING_FIELD_NUMBER: _ClassVar[int]
    labels: str
    major: int
    minor: int
    patch: int
    version_string: str
    def __init__(self, version_string: _Optional[str] = ..., major: _Optional[int] = ..., minor: _Optional[int] = ..., patch: _Optional[int] = ..., labels: _Optional[str] = ...) -> None: ...

class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
EVENT_TYPE_ALL: EventType
EVENT_TYPE_AVAILABLE: EventType
EVENT_TYPE_CREATED: EventType
EVENT_TYPE_DELETED: EventType
EVENT_TYPE_METADATA_UPDATED: EventType
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_UPDATED: EventType

class AcknowledgeMessageBatchRequest(_message.Message):
    __slots__ = ["replies"]
    REPLIES_FIELD_NUMBER: _ClassVar[int]
    replies: _containers.RepeatedCompositeFieldContainer[Reply]
    def __init__(self, replies: _Optional[_Iterable[_Union[Reply, _Mapping]]] = ...) -> None: ...

class AcknowledgeMessageBatchResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateEventStreamingGroupRequest(_message.Message):
    __slots__ = ["hierarchy", "include_subresource", "resource", "resource_id", "stream_all", "stream_from_date", "stream_from_sequence"]
    HIERARCHY_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_SUBRESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    STREAM_ALL_FIELD_NUMBER: _ClassVar[int]
    STREAM_FROM_DATE_FIELD_NUMBER: _ClassVar[int]
    STREAM_FROM_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    hierarchy: EventStreamingGroupHierarchy
    include_subresource: bool
    resource: _models_pb2.ResourceType
    resource_id: str
    stream_all: StreamAll
    stream_from_date: StreamFromDate
    stream_from_sequence: StreamFromSequence
    def __init__(self, resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., include_subresource: bool = ..., stream_all: _Optional[_Union[StreamAll, _Mapping]] = ..., stream_from_date: _Optional[_Union[StreamFromDate, _Mapping]] = ..., stream_from_sequence: _Optional[_Union[StreamFromSequence, _Mapping]] = ..., hierarchy: _Optional[_Union[EventStreamingGroupHierarchy, _Mapping]] = ...) -> None: ...

class CreateEventStreamingGroupResponse(_message.Message):
    __slots__ = ["stream_group_id"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ...) -> None: ...

class DeleteEventStreamingGroupRequest(_message.Message):
    __slots__ = ["stream_group_id"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ...) -> None: ...

class DeleteEventStreamingGroupResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EventNotificationMessage(_message.Message):
    __slots__ = ["reply", "resource", "resource_id", "updated_type"]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_TYPE_FIELD_NUMBER: _ClassVar[int]
    reply: Reply
    resource: _models_pb2.ResourceType
    resource_id: str
    updated_type: EventType
    def __init__(self, resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., updated_type: _Optional[_Union[EventType, str]] = ..., reply: _Optional[_Union[Reply, _Mapping]] = ...) -> None: ...

class EventStreamingGroupHierarchy(_message.Message):
    __slots__ = ["collection_id", "object_group_id", "object_id", "project_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_group_id: str
    object_id: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., object_group_id: _Optional[str] = ...) -> None: ...

class GetEventMessageBatchRequest(_message.Message):
    __slots__ = ["batch_size", "stream_group_id"]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    batch_size: int
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ..., batch_size: _Optional[int] = ...) -> None: ...

class GetEventMessageBatchResponse(_message.Message):
    __slots__ = ["messages"]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[EventNotificationMessage]
    def __init__(self, messages: _Optional[_Iterable[_Union[EventNotificationMessage, _Mapping]]] = ...) -> None: ...

class GetEventMessageBatchStreamRequest(_message.Message):
    __slots__ = ["batch_size", "stream_group_id"]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    batch_size: int
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ..., batch_size: _Optional[int] = ...) -> None: ...

class GetEventMessageBatchStreamResponse(_message.Message):
    __slots__ = ["messages"]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[EventNotificationMessage]
    def __init__(self, messages: _Optional[_Iterable[_Union[EventNotificationMessage, _Mapping]]] = ...) -> None: ...

class Reply(_message.Message):
    __slots__ = ["hmac", "reply", "salt"]
    HMAC_FIELD_NUMBER: _ClassVar[int]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    SALT_FIELD_NUMBER: _ClassVar[int]
    hmac: str
    reply: str
    salt: str
    def __init__(self, reply: _Optional[str] = ..., salt: _Optional[str] = ..., hmac: _Optional[str] = ...) -> None: ...

class StreamAll(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StreamFromDate(_message.Message):
    __slots__ = ["timestamp"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class StreamFromSequence(_message.Message):
    __slots__ = ["sequence"]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    def __init__(self, sequence: _Optional[int] = ...) -> None: ...

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/internal/v1/proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.services.v1 import object_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aruna/api/internal/v1/proxy.proto\x12\x15\x61runa.api.internal.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\x32\x61runa/api/storage/services/v1/object_service.proto\x1a\x1bgoogle/api/visibility.proto\"\xff\x01\n\x08Location\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32#.aruna.api.internal.v1.LocationTypeR\x04type\x12\x16\n\x06\x62ucket\x18\x02 \x01(\tR\x06\x62ucket\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1f\n\x0b\x65ndpoint_id\x18\x04 \x01(\tR\nendpointId\x12#\n\ris_compressed\x18\x05 \x01(\x08R\x0cisCompressed\x12!\n\x0cis_encrypted\x18\x06 \x01(\x08R\x0bisEncrypted\x12%\n\x0e\x65ncryption_key\x18\x07 \x01(\tR\rencryptionKey\"?\n\x08PartETag\x12\x1f\n\x0bpart_number\x18\x01 \x01(\x03R\npartNumber\x12\x12\n\x04\x65tag\x18\x02 \x01(\tR\x04\x65tag\"r\n\x1aInitMultipartUploadRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\":\n\x1bInitMultipartUploadResponse\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\"\xd1\x01\n\x1c\x46inishMultipartUploadRequest\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1b\n\tobject_id\x18\x03 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x04 \x01(\tR\x0c\x63ollectionId\x12>\n\npart_etags\x18\x05 \x03(\x0b\x32\x1f.aruna.api.internal.v1.PartETagR\tpartEtags\"\x1f\n\x1d\x46inishMultipartUploadResponse\"R\n\x13\x44\x65leteObjectRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\"\x16\n\x14\x44\x65leteObjectResponse\"\xf8\x01\n\x15\x46inalizeObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12;\n\x08location\x18\x03 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x39\n\x06hashes\x18\x04 \x03(\x0b\x32!.aruna.api.storage.models.v1.HashR\x06hashes\x12%\n\x0e\x63ontent_length\x18\x05 \x01(\x03R\rcontentLength\"\x18\n\x16\x46inalizeObjectResponse\"j\n\x1fGetOrCreateEncryptionKeyRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04hash\x18\x02 \x01(\tR\x04hash\x12\x1f\n\x0b\x65ndpoint_id\x18\x03 \x01(\tR\nendpointId\"c\n GetOrCreateEncryptionKeyResponse\x12%\n\x0e\x65ncryption_key\x18\x01 \x01(\tR\rencryptionKey\x12\x18\n\x07\x63reated\x18\x02 \x01(\x08R\x07\x63reated\"\xd3\x01\n\x1eGetOrCreateObjectByPathRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1d\n\naccess_key\x18\x02 \x01(\tR\taccessKey\x12\x42\n\x06object\x18\x03 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12\x19\n\x08get_only\x18\x04 \x01(\x08R\x07getOnly\x12\x1f\n\x0b\x65ndpoint_id\x18\x05 \x01(\tR\nendpointId\"\xa7\x02\n\x1fGetOrCreateObjectByPathResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x44\n\tdataclass\x18\x03 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12\x39\n\x06hashes\x18\x04 \x03(\x0b\x32!.aruna.api.storage.models.v1.HashR\x06hashes\x12\'\n\x0frevision_number\x18\x05 \x01(\x03R\x0erevisionNumber\x12\x18\n\x07\x63reated\x18\x06 \x01(\x08R\x07\x63reated\"\x8f\x01\n\x18GetObjectLocationRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1f\n\x0brevision_id\x18\x02 \x01(\tR\nrevisionId\x12\x1d\n\naccess_key\x18\x03 \x01(\tR\taccessKey\x12\x1f\n\x0b\x65ndpoint_id\x18\x04 \x01(\tR\nendpointId\"\x95\x01\n\x19GetObjectLocationResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\x12;\n\x08location\x18\x02 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\"U\n\x1cGetCollectionByBucketRequest\x12\x16\n\x06\x62ucket\x18\x01 \x01(\tR\x06\x62ucket\x12\x1d\n\naccess_key\x18\x02 \x01(\tR\taccessKey\"c\n\x1dGetCollectionByBucketResponse\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId*[\n\x0cLocationType\x12\x1d\n\x19LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10LOCATION_TYPE_S3\x10\x01\x12\x16\n\x12LOCATION_TYPE_FILE\x10\x02\x32\x9a\x03\n\x14InternalProxyService\x12~\n\x13InitMultipartUpload\x12\x31.aruna.api.internal.v1.InitMultipartUploadRequest\x1a\x32.aruna.api.internal.v1.InitMultipartUploadResponse\"\x00\x12\x84\x01\n\x15\x46inishMultipartUpload\x12\x33.aruna.api.internal.v1.FinishMultipartUploadRequest\x1a\x34.aruna.api.internal.v1.FinishMultipartUploadResponse\"\x00\x12i\n\x0c\x44\x65leteObject\x12*.aruna.api.internal.v1.DeleteObjectRequest\x1a+.aruna.api.internal.v1.DeleteObjectResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL2\xbf\x05\n\x1cInternalProxyNotifierService\x12\x8a\x01\n\x17GetOrCreateObjectByPath\x12\x35.aruna.api.internal.v1.GetOrCreateObjectByPathRequest\x1a\x36.aruna.api.internal.v1.GetOrCreateObjectByPathResponse\"\x00\x12o\n\x0e\x46inalizeObject\x12,.aruna.api.internal.v1.FinalizeObjectRequest\x1a-.aruna.api.internal.v1.FinalizeObjectResponse\"\x00\x12\x8d\x01\n\x18GetOrCreateEncryptionKey\x12\x36.aruna.api.internal.v1.GetOrCreateEncryptionKeyRequest\x1a\x37.aruna.api.internal.v1.GetOrCreateEncryptionKeyResponse\"\x00\x12x\n\x11GetObjectLocation\x12/.aruna.api.internal.v1.GetObjectLocationRequest\x1a\x30.aruna.api.internal.v1.GetObjectLocationResponse\"\x00\x12\x84\x01\n\x15GetCollectionByBucket\x12\x33.aruna.api.internal.v1.GetCollectionByBucketRequest\x1a\x34.aruna.api.internal.v1.GetCollectionByBucketResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB6Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.internal.v1.proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1'
  _INTERNALPROXYSERVICE._options = None
  _INTERNALPROXYSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _INTERNALPROXYNOTIFIERSERVICE._options = None
  _INTERNALPROXYNOTIFIERSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _LOCATIONTYPE._serialized_start=2519
  _LOCATIONTYPE._serialized_end=2610
  _LOCATION._serialized_start=184
  _LOCATION._serialized_end=439
  _PARTETAG._serialized_start=441
  _PARTETAG._serialized_end=504
  _INITMULTIPARTUPLOADREQUEST._serialized_start=506
  _INITMULTIPARTUPLOADREQUEST._serialized_end=620
  _INITMULTIPARTUPLOADRESPONSE._serialized_start=622
  _INITMULTIPARTUPLOADRESPONSE._serialized_end=680
  _FINISHMULTIPARTUPLOADREQUEST._serialized_start=683
  _FINISHMULTIPARTUPLOADREQUEST._serialized_end=892
  _FINISHMULTIPARTUPLOADRESPONSE._serialized_start=894
  _FINISHMULTIPARTUPLOADRESPONSE._serialized_end=925
  _DELETEOBJECTREQUEST._serialized_start=927
  _DELETEOBJECTREQUEST._serialized_end=1009
  _DELETEOBJECTRESPONSE._serialized_start=1011
  _DELETEOBJECTRESPONSE._serialized_end=1033
  _FINALIZEOBJECTREQUEST._serialized_start=1036
  _FINALIZEOBJECTREQUEST._serialized_end=1284
  _FINALIZEOBJECTRESPONSE._serialized_start=1286
  _FINALIZEOBJECTRESPONSE._serialized_end=1310
  _GETORCREATEENCRYPTIONKEYREQUEST._serialized_start=1312
  _GETORCREATEENCRYPTIONKEYREQUEST._serialized_end=1418
  _GETORCREATEENCRYPTIONKEYRESPONSE._serialized_start=1420
  _GETORCREATEENCRYPTIONKEYRESPONSE._serialized_end=1519
  _GETORCREATEOBJECTBYPATHREQUEST._serialized_start=1522
  _GETORCREATEOBJECTBYPATHREQUEST._serialized_end=1733
  _GETORCREATEOBJECTBYPATHRESPONSE._serialized_start=1736
  _GETORCREATEOBJECTBYPATHRESPONSE._serialized_end=2031
  _GETOBJECTLOCATIONREQUEST._serialized_start=2034
  _GETOBJECTLOCATIONREQUEST._serialized_end=2177
  _GETOBJECTLOCATIONRESPONSE._serialized_start=2180
  _GETOBJECTLOCATIONRESPONSE._serialized_end=2329
  _GETCOLLECTIONBYBUCKETREQUEST._serialized_start=2331
  _GETCOLLECTIONBYBUCKETREQUEST._serialized_end=2416
  _GETCOLLECTIONBYBUCKETRESPONSE._serialized_start=2418
  _GETCOLLECTIONBYBUCKETRESPONSE._serialized_end=2517
  _INTERNALPROXYSERVICE._serialized_start=2613
  _INTERNALPROXYSERVICE._serialized_end=3023
  _INTERNALPROXYNOTIFIERSERVICE._serialized_start=3026
  _INTERNALPROXYNOTIFIERSERVICE._serialized_end=3729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/models/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'aruna/api/storage/models/v1/query.proto\x12\x1b\x61runa.api.storage.models.v1\x1a(aruna/api/storage/models/v1/models.proto\"G\n\x0bPageRequest\x12\x1b\n\tlast_uuid\x18\x01 \x01(\tR\x08lastUuid\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\"\x85\x01\n\x0bLabelFilter\x12=\n\x06labels\x18\x01 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12\x1a\n\tand_or_or\x18\x02 \x01(\x08R\x07\x61ndOrOr\x12\x1b\n\tkeys_only\x18\x03 \x01(\x08R\x08keysOnly\"d\n\x0eLabelOrIDQuery\x12@\n\x06labels\x18\x01 \x01(\x0b\x32(.aruna.api.storage.models.v1.LabelFilterR\x06labels\x12\x10\n\x03ids\x18\x02 \x03(\tR\x03idsB<Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.models.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1'
  _PAGEREQUEST._serialized_start=114
  _PAGEREQUEST._serialized_end=185
  _LABELFILTER._serialized_start=188
  _LABELFILTER._serialized_end=321
  _LABELORIDQUERY._serialized_start=323
  _LABELORIDQUERY._serialized_end=423
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

from setuptools import setup, find_packages

setup(
    name='Aruna-Python-API',
    version="1.0.0-rc.15",
    description='Aruna Object Storage Python API builds',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/ArunaStorage/python-api',
    license='Apache 2.0',
    author='Marius Dieckmann, Jannis Hochmuth',
    author_email='marius.dieckmann@computational.bio.uni-giessen.de, '
                 'jannis.hochmuth@computational.bio.uni-giessen.de',
    # packages=find_packages('aruna')
    packages=['aruna',
              'aruna.api',
              'aruna.api.internal', 'aruna.api.internal.v1',
              'aruna.api.notification', 'aruna.api.notification.services', 'aruna.api.notification.services.v1',
              'aruna.api.storage',
              'aruna.api.storage.models', 'aruna.api.storage.models.v1',
              'aruna.api.storage.services', 'aruna.api.storage.services.v1'],
    package_data={'aruna.api.internal.v1': ['*.pyi'],
                  'aruna.api.notification.services.v1': ['*.pyi'],
                  'aruna.api.storage.models.v1': ['*.pyi'],
                  'aruna.api.storage.services.v1': ['*.pyi']},
    install_requires=[
        'protobuf==3.20.3',
        'grpcio',
        'grpc-gateway-protoc-gen-openapiv2',
        'google-api-python-client'
    ],
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/collection_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.models.v1 import query_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6aruna/api/storage/services/v1/collection_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\'aruna/api/storage/models/v1/query.proto\x1a\x1cgoogle/api/annotations.proto\"\x86\x03\n\x1a\x43reateNewCollectionRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12=\n\x06labels\x18\x04 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x06 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x44\n\tdataclass\x18\x07 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\"B\n\x1b\x43reateNewCollectionResponse\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\"?\n\x18GetCollectionByIDRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\"l\n\x19GetCollectionByIDResponse\x12O\n\ncollection\x18\x01 \x01(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\ncollection\"\xdd\x01\n\x15GetCollectionsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12X\n\x12label_or_id_filter\x18\x02 \x01(\x0b\x32+.aruna.api.storage.models.v1.LabelOrIDQueryR\x0flabelOrIdFilter\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\"l\n\x16GetCollectionsResponse\x12R\n\x0b\x63ollections\x18\x01 \x01(\x0b\x32\x30.aruna.api.storage.models.v1.CollectionOverviewsR\x0b\x63ollections\"\xc9\x03\n\x17UpdateCollectionRequest\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x06 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x07 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x44\n\tdataclass\x18\x08 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12>\n\x07version\x18\t \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionR\x07version\"k\n\x18UpdateCollectionResponse\x12O\n\ncollection\x18\x01 \x01(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\ncollection\"\x82\x01\n\x1bPinCollectionVersionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12>\n\x07version\x18\x02 \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionR\x07version\"o\n\x1cPinCollectionVersionResponse\x12O\n\ncollection\x18\x01 \x01(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\ncollection\"T\n\x17\x44\x65leteCollectionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x1a\n\x18\x44\x65leteCollectionResponse2\xb7\x08\n\x11\x43ollectionService\x12\xa7\x01\n\x13\x43reateNewCollection\x12\x39.aruna.api.storage.services.v1.CreateNewCollectionRequest\x1a:.aruna.api.storage.services.v1.CreateNewCollectionResponse\"\x19\x82\xd3\xe4\x93\x02\x13:\x01*\"\x0e/v1/collection\x12\xae\x01\n\x11GetCollectionByID\x12\x37.aruna.api.storage.services.v1.GetCollectionByIDRequest\x1a\x38.aruna.api.storage.services.v1.GetCollectionByIDResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/collection/{collection_id}\x12\xa3\x01\n\x0eGetCollections\x12\x34.aruna.api.storage.services.v1.GetCollectionsRequest\x1a\x35.aruna.api.storage.services.v1.GetCollectionsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/collections/{project_id}\x12\xae\x01\n\x10UpdateCollection\x12\x36.aruna.api.storage.services.v1.UpdateCollectionRequest\x1a\x37.aruna.api.storage.services.v1.UpdateCollectionResponse\")\x82\xd3\xe4\x93\x02#:\x01*\x1a\x1e/v1/collection/{collection_id}\x12\xbe\x01\n\x14PinCollectionVersion\x12:.aruna.api.storage.services.v1.PinCollectionVersionRequest\x1a;.aruna.api.storage.services.v1.PinCollectionVersionResponse\"-\x82\xd3\xe4\x93\x02\':\x01*\"\"/v1/collection/{collection_id}/pin\x12\xae\x01\n\x10\x44\x65leteCollection\x12\x36.aruna.api.storage.services.v1.DeleteCollectionRequest\x1a\x37.aruna.api.storage.services.v1.DeleteCollectionResponse\")\x82\xd3\xe4\x93\x02#:\x01**\x1e/v1/collection/{collection_id}B\x93\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x11\x43ollectionServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.collection_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\021CollectionServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _COLLECTIONSERVICE.methods_by_name['CreateNewCollection']._options = None
  _COLLECTIONSERVICE.methods_by_name['CreateNewCollection']._serialized_options = b'\202\323\344\223\002\023:\001*\"\016/v1/collection'
  _COLLECTIONSERVICE.methods_by_name['GetCollectionByID']._options = None
  _COLLECTIONSERVICE.methods_by_name['GetCollectionByID']._serialized_options = b'\202\323\344\223\002 \022\036/v1/collection/{collection_id}'
  _COLLECTIONSERVICE.methods_by_name['GetCollections']._options = None
  _COLLECTIONSERVICE.methods_by_name['GetCollections']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/collections/{project_id}'
  _COLLECTIONSERVICE.methods_by_name['UpdateCollection']._options = None
  _COLLECTIONSERVICE.methods_by_name['UpdateCollection']._serialized_options = b'\202\323\344\223\002#:\001*\032\036/v1/collection/{collection_id}'
  _COLLECTIONSERVICE.methods_by_name['PinCollectionVersion']._options = None
  _COLLECTIONSERVICE.methods_by_name['PinCollectionVersion']._serialized_options = b'\202\323\344\223\002\':\001*\"\"/v1/collection/{collection_id}/pin'
  _COLLECTIONSERVICE.methods_by_name['DeleteCollection']._options = None
  _COLLECTIONSERVICE.methods_by_name['DeleteCollection']._serialized_options = b'\202\323\344\223\002#:\001**\036/v1/collection/{collection_id}'
  _CREATENEWCOLLECTIONREQUEST._serialized_start=203
  _CREATENEWCOLLECTIONREQUEST._serialized_end=593
  _CREATENEWCOLLECTIONRESPONSE._serialized_start=595
  _CREATENEWCOLLECTIONRESPONSE._serialized_end=661
  _GETCOLLECTIONBYIDREQUEST._serialized_start=663
  _GETCOLLECTIONBYIDREQUEST._serialized_end=726
  _GETCOLLECTIONBYIDRESPONSE._serialized_start=728
  _GETCOLLECTIONBYIDRESPONSE._serialized_end=836
  _GETCOLLECTIONSREQUEST._serialized_start=839
  _GETCOLLECTIONSREQUEST._serialized_end=1060
  _GETCOLLECTIONSRESPONSE._serialized_start=1062
  _GETCOLLECTIONSRESPONSE._serialized_end=1170
  _UPDATECOLLECTIONREQUEST._serialized_start=1173
  _UPDATECOLLECTIONREQUEST._serialized_end=1630
  _UPDATECOLLECTIONRESPONSE._serialized_start=1632
  _UPDATECOLLECTIONRESPONSE._serialized_end=1739
  _PINCOLLECTIONVERSIONREQUEST._serialized_start=1742
  _PINCOLLECTIONVERSIONREQUEST._serialized_end=1872
  _PINCOLLECTIONVERSIONRESPONSE._serialized_start=1874
  _PINCOLLECTIONVERSIONRESPONSE._serialized_end=1985
  _DELETECOLLECTIONREQUEST._serialized_start=1987
  _DELETECOLLECTIONREQUEST._serialized_end=2071
  _DELETECOLLECTIONRESPONSE._serialized_start=2073
  _DELETECOLLECTIONRESPONSE._serialized_end=2099
  _COLLECTIONSERVICE._serialized_start=2102
  _COLLECTIONSERVICE._serialized_end=3181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/notification/services/v1/notification_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=aruna/api/notification/services/v1/notification_service.proto\x12\"aruna.api.notification.services.v1\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(aruna/api/storage/models/v1/models.proto\"\xc6\x04\n CreateEventStreamingGroupRequest\x12\x45\n\x08resource\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x08resource\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12/\n\x13include_subresource\x18\x03 \x01(\x08R\x12includeSubresource\x12N\n\nstream_all\x18\x04 \x01(\x0b\x32-.aruna.api.notification.services.v1.StreamAllH\x00R\tstreamAll\x12^\n\x10stream_from_date\x18\x05 \x01(\x0b\x32\x32.aruna.api.notification.services.v1.StreamFromDateH\x00R\x0estreamFromDate\x12j\n\x14stream_from_sequence\x18\x06 \x01(\x0b\x32\x36.aruna.api.notification.services.v1.StreamFromSequenceH\x00R\x12streamFromSequence\x12^\n\thierarchy\x18\x07 \x01(\x0b\x32@.aruna.api.notification.services.v1.EventStreamingGroupHierarchyR\thierarchyB\r\n\x0bstream_type\"\xa7\x01\n\x1c\x45ventStreamingGroupHierarchy\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x03 \x01(\tR\x08objectId\x12&\n\x0fobject_group_id\x18\x04 \x01(\tR\robjectGroupId\"K\n!CreateEventStreamingGroupResponse\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\"d\n\x1bGetEventMessageBatchRequest\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\x12\x1d\n\nbatch_size\x18\x02 \x01(\rR\tbatchSize\"x\n\x1cGetEventMessageBatchResponse\x12X\n\x08messages\x18\x01 \x03(\x0b\x32<.aruna.api.notification.services.v1.EventNotificationMessageR\x08messages\"j\n!GetEventMessageBatchStreamRequest\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\x12\x1d\n\nbatch_size\x18\x02 \x01(\rR\tbatchSize\"~\n\"GetEventMessageBatchStreamResponse\x12X\n\x08messages\x18\x01 \x03(\x0b\x32<.aruna.api.notification.services.v1.EventNotificationMessageR\x08messages\"e\n\x1e\x41\x63knowledgeMessageBatchRequest\x12\x43\n\x07replies\x18\x01 \x03(\x0b\x32).aruna.api.notification.services.v1.ReplyR\x07replies\"!\n\x1f\x41\x63knowledgeMessageBatchResponse\"J\n DeleteEventStreamingGroupRequest\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\"#\n!DeleteEventStreamingGroupResponse\"0\n\x12StreamFromSequence\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\"J\n\x0eStreamFromDate\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x0b\n\tStreamAll\"\x95\x02\n\x18\x45ventNotificationMessage\x12\x45\n\x08resource\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x08resource\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12P\n\x0cupdated_type\x18\x03 \x01(\x0e\x32-.aruna.api.notification.services.v1.EventTypeR\x0bupdatedType\x12?\n\x05reply\x18\x04 \x01(\x0b\x32).aruna.api.notification.services.v1.ReplyR\x05reply\"E\n\x05Reply\x12\x14\n\x05reply\x18\x01 \x01(\tR\x05reply\x12\x12\n\x04salt\x18\x02 \x01(\tR\x04salt\x12\x12\n\x04hmac\x18\x03 \x01(\tR\x04hmac*\xbe\x01\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45VENT_TYPE_CREATED\x10\x01\x12\x18\n\x14\x45VENT_TYPE_AVAILABLE\x10\x02\x12\x16\n\x12\x45VENT_TYPE_UPDATED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_METADATA_UPDATED\x10\x04\x12\x16\n\x12\x45VENT_TYPE_DELETED\x10\x05\x12\x12\n\x0e\x45VENT_TYPE_ALL\x10\x06\x32\xff\x06\n\x18\x45ventNotificationService\x12\xaa\x01\n\x19\x43reateEventStreamingGroup\x12\x44.aruna.api.notification.services.v1.CreateEventStreamingGroupRequest\x1a\x45.aruna.api.notification.services.v1.CreateEventStreamingGroupResponse\"\x00\x12\x9b\x01\n\x14GetEventMessageBatch\x12?.aruna.api.notification.services.v1.GetEventMessageBatchRequest\x1a@.aruna.api.notification.services.v1.GetEventMessageBatchResponse\"\x00\x12\xaf\x01\n\x1aGetEventMessageBatchStream\x12\x45.aruna.api.notification.services.v1.GetEventMessageBatchStreamRequest\x1a\x46.aruna.api.notification.services.v1.GetEventMessageBatchStreamResponse\"\x00\x30\x01\x12\xa4\x01\n\x17\x41\x63knowledgeMessageBatch\x12\x42.aruna.api.notification.services.v1.AcknowledgeMessageBatchRequest\x1a\x43.aruna.api.notification.services.v1.AcknowledgeMessageBatchResponse\"\x00\x12\xaa\x01\n\x19\x44\x65leteEventStreamingGroup\x12\x44.aruna.api.notification.services.v1.DeleteEventStreamingGroupRequest\x1a\x45.aruna.api.notification.services.v1.DeleteEventStreamingGroupResponse\"\x00\x1a\x12\xfa\xd2\xe4\x93\x02\x0c\x12\nUNFINISHEDB\x9c\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x1aUpdateNotificationServicesP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.notification.services.v1.notification_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\032UpdateNotificationServicesP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _EVENTNOTIFICATIONSERVICE._options = None
  _EVENTNOTIFICATIONSERVICE._serialized_options = b'\372\322\344\223\002\014\022\nUNFINISHED'
  _EVENTTYPE._serialized_start=2239
  _EVENTTYPE._serialized_end=2429
  _CREATEEVENTSTREAMINGGROUPREQUEST._serialized_start=206
  _CREATEEVENTSTREAMINGGROUPREQUEST._serialized_end=788
  _EVENTSTREAMINGGROUPHIERARCHY._serialized_start=791
  _EVENTSTREAMINGGROUPHIERARCHY._serialized_end=958
  _CREATEEVENTSTREAMINGGROUPRESPONSE._serialized_start=960
  _CREATEEVENTSTREAMINGGROUPRESPONSE._serialized_end=1035
  _GETEVENTMESSAGEBATCHREQUEST._serialized_start=1037
  _GETEVENTMESSAGEBATCHREQUEST._serialized_end=1137
  _GETEVENTMESSAGEBATCHRESPONSE._serialized_start=1139
  _GETEVENTMESSAGEBATCHRESPONSE._serialized_end=1259
  _GETEVENTMESSAGEBATCHSTREAMREQUEST._serialized_start=1261
  _GETEVENTMESSAGEBATCHSTREAMREQUEST._serialized_end=1367
  _GETEVENTMESSAGEBATCHSTREAMRESPONSE._serialized_start=1369
  _GETEVENTMESSAGEBATCHSTREAMRESPONSE._serialized_end=1495
  _ACKNOWLEDGEMESSAGEBATCHREQUEST._serialized_start=1497
  _ACKNOWLEDGEMESSAGEBATCHREQUEST._serialized_end=1598
  _ACKNOWLEDGEMESSAGEBATCHRESPONSE._serialized_start=1600
  _ACKNOWLEDGEMESSAGEBATCHRESPONSE._serialized_end=1633
  _DELETEEVENTSTREAMINGGROUPREQUEST._serialized_start=1635
  _DELETEEVENTSTREAMINGGROUPREQUEST._serialized_end=1709
  _DELETEEVENTSTREAMINGGROUPRESPONSE._serialized_start=1711
  _DELETEEVENTSTREAMINGGROUPRESPONSE._serialized_end=1746
  _STREAMFROMSEQUENCE._serialized_start=1748
  _STREAMFROMSEQUENCE._serialized_end=1796
  _STREAMFROMDATE._serialized_start=1798
  _STREAMFROMDATE._serialized_end=1872
  _STREAMALL._serialized_start=1874
  _STREAMALL._serialized_end=1885
  _EVENTNOTIFICATIONMESSAGE._serialized_start=1888
  _EVENTNOTIFICATIONMESSAGE._serialized_end=2165
  _REPLY._serialized_start=2167
  _REPLY._serialized_end=2236
  _EVENTNOTIFICATIONSERVICE._serialized_start=2432
  _EVENTNOTIFICATIONSERVICE._serialized_end=3327
# @@protoc_insertion_point(module_scope)



from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from aruna.api.storage.models.v1 import query_pb2 as _query_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddLabelsToObjectRequest(_message.Message):
    __slots__ = ["collection_id", "labels_to_add", "object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_TO_ADD_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    labels_to_add: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    object_id: str
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., labels_to_add: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ...) -> None: ...

class AddLabelsToObjectResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: _models_pb2.Object
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ...) -> None: ...

class CloneObjectRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "target_collection_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    target_collection_id: str
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., target_collection_id: _Optional[str] = ...) -> None: ...

class CloneObjectResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: _models_pb2.Object
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ...) -> None: ...

class CompletedParts(_message.Message):
    __slots__ = ["etag", "part"]
    ETAG_FIELD_NUMBER: _ClassVar[int]
    PART_FIELD_NUMBER: _ClassVar[int]
    etag: str
    part: int
    def __init__(self, etag: _Optional[str] = ..., part: _Optional[int] = ...) -> None: ...

class CreateDownloadLinksStreamRequest(_message.Message):
    __slots__ = ["collection_id", "objects"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    objects: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, collection_id: _Optional[str] = ..., objects: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateDownloadLinksStreamResponse(_message.Message):
    __slots__ = ["url"]
    URL_FIELD_NUMBER: _ClassVar[int]
    url: URL
    def __init__(self, url: _Optional[_Union[URL, _Mapping]] = ...) -> None: ...

class CreateObjectPathRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "sub_path"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SUB_PATH_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    sub_path: str
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., sub_path: _Optional[str] = ...) -> None: ...

class CreateObjectPathResponse(_message.Message):
    __slots__ = ["path"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: Path
    def __init__(self, path: _Optional[_Union[Path, _Mapping]] = ...) -> None: ...

class CreateObjectReferenceRequest(_message.Message):
    __slots__ = ["auto_update", "collection_id", "object_id", "sub_path", "target_collection_id", "writeable"]
    AUTO_UPDATE_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SUB_PATH_FIELD_NUMBER: _ClassVar[int]
    TARGET_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    WRITEABLE_FIELD_NUMBER: _ClassVar[int]
    auto_update: bool
    collection_id: str
    object_id: str
    sub_path: str
    target_collection_id: str
    writeable: bool
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., target_collection_id: _Optional[str] = ..., writeable: bool = ..., auto_update: bool = ..., sub_path: _Optional[str] = ...) -> None: ...

class CreateObjectReferenceResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteObjectRequest(_message.Message):
    __slots__ = ["collection_id", "force", "object_id", "with_revisions"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    WITH_REVISIONS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    force: bool
    object_id: str
    with_revisions: bool
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., with_revisions: bool = ..., force: bool = ...) -> None: ...

class DeleteObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteObjectsRequest(_message.Message):
    __slots__ = ["collection_id", "force", "object_ids", "with_revisions"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    WITH_REVISIONS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    force: bool
    object_ids: _containers.RepeatedScalarFieldContainer[str]
    with_revisions: bool
    def __init__(self, object_ids: _Optional[_Iterable[str]] = ..., collection_id: _Optional[str] = ..., with_revisions: bool = ..., force: bool = ...) -> None: ...

class DeleteObjectsResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FinishObjectStagingRequest(_message.Message):
    __slots__ = ["auto_update", "collection_id", "completed_parts", "hash", "no_upload", "object_id", "upload_id"]
    AUTO_UPDATE_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_PARTS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    NO_UPLOAD_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    auto_update: bool
    collection_id: str
    completed_parts: _containers.RepeatedCompositeFieldContainer[CompletedParts]
    hash: _models_pb2.Hash
    no_upload: bool
    object_id: str
    upload_id: str
    def __init__(self, object_id: _Optional[str] = ..., upload_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., hash: _Optional[_Union[_models_pb2.Hash, _Mapping]] = ..., no_upload: bool = ..., completed_parts: _Optional[_Iterable[_Union[CompletedParts, _Mapping]]] = ..., auto_update: bool = ...) -> None: ...

class FinishObjectStagingResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: _models_pb2.Object
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ...) -> None: ...

class GetDownloadLinksBatchRequest(_message.Message):
    __slots__ = ["collection_id", "objects"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    objects: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, collection_id: _Optional[str] = ..., objects: _Optional[_Iterable[str]] = ...) -> None: ...

class GetDownloadLinksBatchResponse(_message.Message):
    __slots__ = ["urls"]
    URLS_FIELD_NUMBER: _ClassVar[int]
    urls: _containers.RepeatedCompositeFieldContainer[URL]
    def __init__(self, urls: _Optional[_Iterable[_Union[URL, _Mapping]]] = ...) -> None: ...

class GetDownloadURLRequest(_message.Message):
    __slots__ = ["collection_id", "object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ...) -> None: ...

class GetDownloadURLResponse(_message.Message):
    __slots__ = ["url"]
    URL_FIELD_NUMBER: _ClassVar[int]
    url: URL
    def __init__(self, url: _Optional[_Union[URL, _Mapping]] = ...) -> None: ...

class GetLatestObjectRevisionRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "with_url"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    WITH_URL_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    with_url: bool
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., with_url: bool = ...) -> None: ...

class GetLatestObjectRevisionResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: ObjectWithURL
    def __init__(self, object: _Optional[_Union[ObjectWithURL, _Mapping]] = ...) -> None: ...

class GetObjectByIDRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "with_url"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    WITH_URL_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    with_url: bool
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., with_url: bool = ...) -> None: ...

class GetObjectByIDResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: ObjectWithURL
    def __init__(self, object: _Optional[_Union[ObjectWithURL, _Mapping]] = ...) -> None: ...

class GetObjectEndpointsRequest(_message.Message):
    __slots__ = ["collection_id", "object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ...) -> None: ...

class GetObjectEndpointsResponse(_message.Message):
    __slots__ = ["endpoints"]
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    endpoints: _containers.RepeatedCompositeFieldContainer[_models_pb2.Endpoint]
    def __init__(self, endpoints: _Optional[_Iterable[_Union[_models_pb2.Endpoint, _Mapping]]] = ...) -> None: ...

class GetObjectPathRequest(_message.Message):
    __slots__ = ["collection_id", "include_inactive", "object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_INACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    include_inactive: bool
    object_id: str
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., include_inactive: bool = ...) -> None: ...

class GetObjectPathResponse(_message.Message):
    __slots__ = ["object_paths"]
    OBJECT_PATHS_FIELD_NUMBER: _ClassVar[int]
    object_paths: _containers.RepeatedCompositeFieldContainer[Path]
    def __init__(self, object_paths: _Optional[_Iterable[_Union[Path, _Mapping]]] = ...) -> None: ...

class GetObjectPathsRequest(_message.Message):
    __slots__ = ["collection_id", "include_inactive"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_INACTIVE_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    include_inactive: bool
    def __init__(self, collection_id: _Optional[str] = ..., include_inactive: bool = ...) -> None: ...

class GetObjectPathsResponse(_message.Message):
    __slots__ = ["object_paths"]
    OBJECT_PATHS_FIELD_NUMBER: _ClassVar[int]
    object_paths: _containers.RepeatedCompositeFieldContainer[Path]
    def __init__(self, object_paths: _Optional[_Iterable[_Union[Path, _Mapping]]] = ...) -> None: ...

class GetObjectRevisionsRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "page_request", "with_url"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    WITH_URL_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    page_request: _query_pb2.PageRequest
    with_url: bool
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ..., with_url: bool = ...) -> None: ...

class GetObjectRevisionsResponse(_message.Message):
    __slots__ = ["objects"]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    objects: _containers.RepeatedCompositeFieldContainer[ObjectWithURL]
    def __init__(self, objects: _Optional[_Iterable[_Union[ObjectWithURL, _Mapping]]] = ...) -> None: ...

class GetObjectsByPathRequest(_message.Message):
    __slots__ = ["path", "with_revisions"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    WITH_REVISIONS_FIELD_NUMBER: _ClassVar[int]
    path: str
    with_revisions: bool
    def __init__(self, path: _Optional[str] = ..., with_revisions: bool = ...) -> None: ...

class GetObjectsByPathResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: _containers.RepeatedCompositeFieldContainer[_models_pb2.Object]
    def __init__(self, object: _Optional[_Iterable[_Union[_models_pb2.Object, _Mapping]]] = ...) -> None: ...

class GetObjectsRequest(_message.Message):
    __slots__ = ["collection_id", "label_id_filter", "page_request", "with_url"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    LABEL_ID_FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    WITH_URL_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    label_id_filter: _query_pb2.LabelOrIDQuery
    page_request: _query_pb2.PageRequest
    with_url: bool
    def __init__(self, collection_id: _Optional[str] = ..., page_request: _Optional[_Union[_query_pb2.PageRequest, _Mapping]] = ..., label_id_filter: _Optional[_Union[_query_pb2.LabelOrIDQuery, _Mapping]] = ..., with_url: bool = ...) -> None: ...

class GetObjectsResponse(_message.Message):
    __slots__ = ["objects"]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    objects: _containers.RepeatedCompositeFieldContainer[ObjectWithURL]
    def __init__(self, objects: _Optional[_Iterable[_Union[ObjectWithURL, _Mapping]]] = ...) -> None: ...

class GetProjectCollectionIdsByPathRequest(_message.Message):
    __slots__ = ["path"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: str
    def __init__(self, path: _Optional[str] = ...) -> None: ...

class GetProjectCollectionIdsByPathResponse(_message.Message):
    __slots__ = ["collection_id", "project_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class GetReferencesRequest(_message.Message):
    __slots__ = ["collection_id", "object_id", "with_revisions"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    WITH_REVISIONS_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    with_revisions: bool
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., with_revisions: bool = ...) -> None: ...

class GetReferencesResponse(_message.Message):
    __slots__ = ["references"]
    REFERENCES_FIELD_NUMBER: _ClassVar[int]
    references: _containers.RepeatedCompositeFieldContainer[ObjectReference]
    def __init__(self, references: _Optional[_Iterable[_Union[ObjectReference, _Mapping]]] = ...) -> None: ...

class GetUploadURLRequest(_message.Message):
    __slots__ = ["collection_id", "multipart", "object_id", "part_number", "upload_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    multipart: bool
    object_id: str
    part_number: int
    upload_id: str
    def __init__(self, object_id: _Optional[str] = ..., upload_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., multipart: bool = ..., part_number: _Optional[int] = ...) -> None: ...

class GetUploadURLResponse(_message.Message):
    __slots__ = ["url"]
    URL_FIELD_NUMBER: _ClassVar[int]
    url: URL
    def __init__(self, url: _Optional[_Union[URL, _Mapping]] = ...) -> None: ...

class InitializeNewObjectRequest(_message.Message):
    __slots__ = ["collection_id", "hash", "is_specification", "multipart", "object", "preferred_endpoint_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    IS_SPECIFICATION_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    hash: _models_pb2.Hash
    is_specification: bool
    multipart: bool
    object: StageObject
    preferred_endpoint_id: str
    def __init__(self, object: _Optional[_Union[StageObject, _Mapping]] = ..., collection_id: _Optional[str] = ..., preferred_endpoint_id: _Optional[str] = ..., multipart: bool = ..., is_specification: bool = ..., hash: _Optional[_Union[_models_pb2.Hash, _Mapping]] = ...) -> None: ...

class InitializeNewObjectResponse(_message.Message):
    __slots__ = ["collection_id", "object_id", "upload_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    upload_id: str
    def __init__(self, object_id: _Optional[str] = ..., upload_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class ObjectReference(_message.Message):
    __slots__ = ["collection_id", "is_writeable", "object_id", "revision_number"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    IS_WRITEABLE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    is_writeable: bool
    object_id: str
    revision_number: int
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., revision_number: _Optional[int] = ..., is_writeable: bool = ...) -> None: ...

class ObjectWithURL(_message.Message):
    __slots__ = ["object", "paths", "url"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    PATHS_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    object: _models_pb2.Object
    paths: _containers.RepeatedScalarFieldContainer[str]
    url: str
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ..., url: _Optional[str] = ..., paths: _Optional[_Iterable[str]] = ...) -> None: ...

class Path(_message.Message):
    __slots__ = ["path", "visibility"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    path: str
    visibility: bool
    def __init__(self, path: _Optional[str] = ..., visibility: bool = ...) -> None: ...

class SetHooksOfObjectRequest(_message.Message):
    __slots__ = ["collection_id", "hooks", "object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    hooks: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    object_id: str
    def __init__(self, collection_id: _Optional[str] = ..., object_id: _Optional[str] = ..., hooks: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ...) -> None: ...

class SetHooksOfObjectResponse(_message.Message):
    __slots__ = ["object"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: _models_pb2.Object
    def __init__(self, object: _Optional[_Union[_models_pb2.Object, _Mapping]] = ...) -> None: ...

class SetObjectPathVisibilityRequest(_message.Message):
    __slots__ = ["collection_id", "path", "visibility"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    path: str
    visibility: bool
    def __init__(self, collection_id: _Optional[str] = ..., path: _Optional[str] = ..., visibility: bool = ...) -> None: ...

class SetObjectPathVisibilityResponse(_message.Message):
    __slots__ = ["path"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: Path
    def __init__(self, path: _Optional[_Union[Path, _Mapping]] = ...) -> None: ...

class StageObject(_message.Message):
    __slots__ = ["content_len", "dataclass", "filename", "hooks", "labels", "source", "sub_path"]
    CONTENT_LEN_FIELD_NUMBER: _ClassVar[int]
    DATACLASS_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SUB_PATH_FIELD_NUMBER: _ClassVar[int]
    content_len: int
    dataclass: _models_pb2.DataClass
    filename: str
    hooks: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    labels: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    source: _models_pb2.Source
    sub_path: str
    def __init__(self, filename: _Optional[str] = ..., content_len: _Optional[int] = ..., source: _Optional[_Union[_models_pb2.Source, _Mapping]] = ..., dataclass: _Optional[_Union[_models_pb2.DataClass, str]] = ..., labels: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., sub_path: _Optional[str] = ...) -> None: ...

class URL(_message.Message):
    __slots__ = ["url"]
    URL_FIELD_NUMBER: _ClassVar[int]
    url: str
    def __init__(self, url: _Optional[str] = ...) -> None: ...

class UpdateObjectRequest(_message.Message):
    __slots__ = ["collection_id", "hash", "is_specification", "multi_part", "object", "object_id", "preferred_endpoint_id", "reupload"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    IS_SPECIFICATION_FIELD_NUMBER: _ClassVar[int]
    MULTI_PART_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_ENDPOINT_ID_FIELD_NUMBER: _ClassVar[int]
    REUPLOAD_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    hash: _models_pb2.Hash
    is_specification: bool
    multi_part: bool
    object: StageObject
    object_id: str
    preferred_endpoint_id: str
    reupload: bool
    def __init__(self, object_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., object: _Optional[_Union[StageObject, _Mapping]] = ..., reupload: bool = ..., preferred_endpoint_id: _Optional[str] = ..., multi_part: bool = ..., is_specification: bool = ..., hash: _Optional[_Union[_models_pb2.Hash, _Mapping]] = ...) -> None: ...

class UpdateObjectResponse(_message.Message):
    __slots__ = ["collection_id", "object_id", "staging_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    STAGING_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    staging_id: str
    def __init__(self, object_id: _Optional[str] = ..., staging_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...



from aruna.api.storage.models.v1 import auth_pb2 as _auth_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateServiceAccountRequest(_message.Message):
    __slots__ = ["name", "permission", "project_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    permission: _auth_pb2.Permission
    project_id: str
    def __init__(self, name: _Optional[str] = ..., project_id: _Optional[str] = ..., permission: _Optional[_Union[_auth_pb2.Permission, str]] = ...) -> None: ...

class CreateServiceAccountResponse(_message.Message):
    __slots__ = ["service_account"]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    service_account: ServiceAccount
    def __init__(self, service_account: _Optional[_Union[ServiceAccount, _Mapping]] = ...) -> None: ...

class CreateServiceAccountTokenRequest(_message.Message):
    __slots__ = ["collection_id", "expires_at", "name", "permission", "svc_account_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    expires_at: _timestamp_pb2.Timestamp
    name: str
    permission: _auth_pb2.Permission
    svc_account_id: str
    def __init__(self, svc_account_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., name: _Optional[str] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., permission: _Optional[_Union[_auth_pb2.Permission, str]] = ...) -> None: ...

class CreateServiceAccountTokenResponse(_message.Message):
    __slots__ = ["token", "token_secret"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_SECRET_FIELD_NUMBER: _ClassVar[int]
    token: _auth_pb2.Token
    token_secret: str
    def __init__(self, token: _Optional[_Union[_auth_pb2.Token, _Mapping]] = ..., token_secret: _Optional[str] = ...) -> None: ...

class DeleteServiceAccountRequest(_message.Message):
    __slots__ = ["svc_account_id"]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    svc_account_id: str
    def __init__(self, svc_account_id: _Optional[str] = ...) -> None: ...

class DeleteServiceAccountResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteServiceAccountTokenRequest(_message.Message):
    __slots__ = ["svc_account_id", "token_id"]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ID_FIELD_NUMBER: _ClassVar[int]
    svc_account_id: str
    token_id: str
    def __init__(self, svc_account_id: _Optional[str] = ..., token_id: _Optional[str] = ...) -> None: ...

class DeleteServiceAccountTokenResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteServiceAccountTokensRequest(_message.Message):
    __slots__ = ["svc_account_id"]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    svc_account_id: str
    def __init__(self, svc_account_id: _Optional[str] = ...) -> None: ...

class DeleteServiceAccountTokensResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EditServiceAccountPermissionRequest(_message.Message):
    __slots__ = ["new_permission", "svc_account_id"]
    NEW_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    new_permission: _auth_pb2.Permission
    svc_account_id: str
    def __init__(self, svc_account_id: _Optional[str] = ..., new_permission: _Optional[_Union[_auth_pb2.Permission, str]] = ...) -> None: ...

class EditServiceAccountPermissionResponse(_message.Message):
    __slots__ = ["service_account"]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    service_account: ServiceAccount
    def __init__(self, service_account: _Optional[_Union[ServiceAccount, _Mapping]] = ...) -> None: ...

class GetServiceAccountTokenRequest(_message.Message):
    __slots__ = ["svc_account_id", "token_id"]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ID_FIELD_NUMBER: _ClassVar[int]
    svc_account_id: str
    token_id: str
    def __init__(self, svc_account_id: _Optional[str] = ..., token_id: _Optional[str] = ...) -> None: ...

class GetServiceAccountTokenResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: _auth_pb2.Token
    def __init__(self, token: _Optional[_Union[_auth_pb2.Token, _Mapping]] = ...) -> None: ...

class GetServiceAccountTokensRequest(_message.Message):
    __slots__ = ["svc_account_id"]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    svc_account_id: str
    def __init__(self, svc_account_id: _Optional[str] = ...) -> None: ...

class GetServiceAccountTokensResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: _containers.RepeatedCompositeFieldContainer[_auth_pb2.Token]
    def __init__(self, token: _Optional[_Iterable[_Union[_auth_pb2.Token, _Mapping]]] = ...) -> None: ...

class GetServiceAccountsByProjectRequest(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class GetServiceAccountsByProjectResponse(_message.Message):
    __slots__ = ["svc_accounts"]
    SVC_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    svc_accounts: _containers.RepeatedCompositeFieldContainer[ServiceAccount]
    def __init__(self, svc_accounts: _Optional[_Iterable[_Union[ServiceAccount, _Mapping]]] = ...) -> None: ...

class ServiceAccount(_message.Message):
    __slots__ = ["name", "permission", "project_id", "svc_account_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SVC_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    permission: _auth_pb2.Permission
    project_id: str
    svc_account_id: str
    def __init__(self, svc_account_id: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ..., permission: _Optional[_Union[_auth_pb2.Permission, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import auth_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_auth__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0aruna/api/storage/services/v1/user_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a&aruna/api/storage/models/v1/auth.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"E\n\tExpiresAt\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"h\n\x13RegisterUserRequest\x12!\n\x0c\x64isplay_name\x18\x01 \x01(\tR\x0b\x64isplayName\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x18\n\x07project\x18\x03 \x01(\tR\x07project\"/\n\x14RegisterUserResponse\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\xa0\x02\n\x15\x43reateAPITokenRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12G\n\nexpires_at\x18\x04 \x01(\x0b\x32(.aruna.api.storage.services.v1.ExpiresAtR\texpiresAt\x12G\n\npermission\x18\x05 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\x12\x1d\n\nis_session\x18\x06 \x01(\x08R\tisSession\"\xbd\x01\n\x16\x43reateAPITokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\x12!\n\x0ctoken_secret\x18\x02 \x01(\tR\x0btokenSecret\x12\"\n\rs3_access_key\x18\x03 \x01(\tR\x0bs3AccessKey\x12\"\n\rs3_secret_key\x18\x04 \x01(\tR\x0bs3SecretKey\"/\n\x12GetAPITokenRequest\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\"O\n\x13GetAPITokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\"\x15\n\x13GetAPITokensRequest\"P\n\x14GetAPITokensResponse\x12\x38\n\x05token\x18\x01 \x03(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\"2\n\x15\x44\x65leteAPITokenRequest\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\"\x18\n\x16\x44\x65leteAPITokenResponse\"1\n\x16\x44\x65leteAPITokensRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\x19\n\x17\x44\x65leteAPITokensResponse\")\n\x0eGetUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\xa9\x01\n\x0fGetUserResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.aruna.api.storage.models.v1.UserR\x04user\x12_\n\x13project_permissions\x18\x02 \x03(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x12projectPermissions\"H\n\x1cUpdateUserDisplayNameRequest\x12(\n\x10new_display_name\x18\x01 \x01(\tR\x0enewDisplayName\"V\n\x1dUpdateUserDisplayNameResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.aruna.api.storage.models.v1.UserR\x04user\"1\n\x16GetUserProjectsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"S\n\x0bUserProject\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"a\n\x17GetUserProjectsResponse\x12\x46\n\x08projects\x18\x01 \x03(\x0b\x32*.aruna.api.storage.services.v1.UserProjectR\x08projects\"\x83\x01\n\x13\x41\x63tivateUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12S\n\rproject_perms\x18\x02 \x01(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x0cprojectPerms\"\x16\n\x14\x41\x63tivateUserResponse\"\x1d\n\x1bGetNotActivatedUsersRequest\"W\n\x1cGetNotActivatedUsersResponse\x12\x37\n\x05users\x18\x01 \x03(\x0b\x32!.aruna.api.storage.models.v1.UserR\x05users\"E\n\x12GetAllUsersRequest\x12/\n\x13include_permissions\x18\x01 \x01(\x08R\x12includePermissions\"\x9b\x01\n\rUserWithPerms\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.aruna.api.storage.models.v1.UserR\x04user\x12S\n\rproject_perms\x18\x02 \x03(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x0cprojectPerms\"k\n\x13GetAllUsersResponse\x12T\n\x0fuser_with_perms\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.UserWithPermsR\ruserWithPerms\"0\n\x15\x44\x65\x61\x63tivateUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\x18\n\x16\x44\x65\x61\x63tivateUserResponse\"N\n\x16UpdateUserEmailRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1b\n\tnew_email\x18\x02 \x01(\tR\x08newEmail\"P\n\x17UpdateUserEmailResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.aruna.api.storage.models.v1.UserR\x04user2\xb0\x11\n\x0bUserService\x12\x95\x01\n\x0cRegisterUser\x12\x32.aruna.api.storage.services.v1.RegisterUserRequest\x1a\x33.aruna.api.storage.services.v1.RegisterUserResponse\"\x1c\x82\xd3\xe4\x93\x02\x16:\x01*\"\x11/v1/auth/register\x12\xa7\x01\n\x0e\x44\x65\x61\x63tivateUser\x12\x34.aruna.api.storage.services.v1.DeactivateUserRequest\x1a\x35.aruna.api.storage.services.v1.DeactivateUserResponse\"(\x82\xd3\xe4\x93\x02\":\x01*2\x1d/v1/user/{user_id}/deactivate\x12\x9f\x01\n\x0c\x41\x63tivateUser\x12\x32.aruna.api.storage.services.v1.ActivateUserRequest\x1a\x33.aruna.api.storage.services.v1.ActivateUserResponse\"&\x82\xd3\xe4\x93\x02 :\x01*2\x1b/v1/user/{user_id}/activate\x12\x98\x01\n\x0e\x43reateAPIToken\x12\x34.aruna.api.storage.services.v1.CreateAPITokenRequest\x1a\x35.aruna.api.storage.services.v1.CreateAPITokenResponse\"\x19\x82\xd3\xe4\x93\x02\x13:\x01*\"\x0e/v1/auth/token\x12\x97\x01\n\x0bGetAPIToken\x12\x31.aruna.api.storage.services.v1.GetAPITokenRequest\x1a\x32.aruna.api.storage.services.v1.GetAPITokenResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/auth/token/{token_id}\x12\x90\x01\n\x0cGetAPITokens\x12\x32.aruna.api.storage.services.v1.GetAPITokensRequest\x1a\x33.aruna.api.storage.services.v1.GetAPITokensResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/auth/tokens\x12\xa0\x01\n\x0e\x44\x65leteAPIToken\x12\x34.aruna.api.storage.services.v1.DeleteAPITokenRequest\x1a\x35.aruna.api.storage.services.v1.DeleteAPITokenResponse\"!\x82\xd3\xe4\x93\x02\x1b*\x19/v1/auth/token/{token_id}\x12\x99\x01\n\x0f\x44\x65leteAPITokens\x12\x35.aruna.api.storage.services.v1.DeleteAPITokensRequest\x1a\x36.aruna.api.storage.services.v1.DeleteAPITokensResponse\"\x17\x82\xd3\xe4\x93\x02\x11*\x0f/v1/auth/tokens\x12z\n\x07GetUser\x12-.aruna.api.storage.services.v1.GetUserRequest\x1a..aruna.api.storage.services.v1.GetUserResponse\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/user\x12\xb4\x01\n\x15UpdateUserDisplayName\x12;.aruna.api.storage.services.v1.UpdateUserDisplayNameRequest\x1a<.aruna.api.storage.services.v1.UpdateUserDisplayNameResponse\" \x82\xd3\xe4\x93\x02\x1a:\x01*2\x15/v1/user/display_name\x12\x9b\x01\n\x0fUpdateUserEmail\x12\x35.aruna.api.storage.services.v1.UpdateUserEmailRequest\x1a\x36.aruna.api.storage.services.v1.UpdateUserEmailResponse\"\x19\x82\xd3\xe4\x93\x02\x13:\x01*2\x0e/v1/user/email\x12\xa5\x01\n\x0fGetUserProjects\x12\x35.aruna.api.storage.services.v1.GetUserProjectsRequest\x1a\x36.aruna.api.storage.services.v1.GetUserProjectsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/user/{user_id}/projects\x12\xaf\x01\n\x14GetNotActivatedUsers\x12:.aruna.api.storage.services.v1.GetNotActivatedUsersRequest\x1a;.aruna.api.storage.services.v1.GetNotActivatedUsersResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/user/not_activated\x12\x8a\x01\n\x0bGetAllUsers\x12\x31.aruna.api.storage.services.v1.GetAllUsersRequest\x1a\x32.aruna.api.storage.services.v1.GetAllUsersResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/user/allB\x8d\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x0bUserServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\013UserServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _USERSERVICE.methods_by_name['RegisterUser']._options = None
  _USERSERVICE.methods_by_name['RegisterUser']._serialized_options = b'\202\323\344\223\002\026:\001*\"\021/v1/auth/register'
  _USERSERVICE.methods_by_name['DeactivateUser']._options = None
  _USERSERVICE.methods_by_name['DeactivateUser']._serialized_options = b'\202\323\344\223\002\":\001*2\035/v1/user/{user_id}/deactivate'
  _USERSERVICE.methods_by_name['ActivateUser']._options = None
  _USERSERVICE.methods_by_name['ActivateUser']._serialized_options = b'\202\323\344\223\002 :\001*2\033/v1/user/{user_id}/activate'
  _USERSERVICE.methods_by_name['CreateAPIToken']._options = None
  _USERSERVICE.methods_by_name['CreateAPIToken']._serialized_options = b'\202\323\344\223\002\023:\001*\"\016/v1/auth/token'
  _USERSERVICE.methods_by_name['GetAPIToken']._options = None
  _USERSERVICE.methods_by_name['GetAPIToken']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/auth/token/{token_id}'
  _USERSERVICE.methods_by_name['GetAPITokens']._options = None
  _USERSERVICE.methods_by_name['GetAPITokens']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/auth/tokens'
  _USERSERVICE.methods_by_name['DeleteAPIToken']._options = None
  _USERSERVICE.methods_by_name['DeleteAPIToken']._serialized_options = b'\202\323\344\223\002\033*\031/v1/auth/token/{token_id}'
  _USERSERVICE.methods_by_name['DeleteAPITokens']._options = None
  _USERSERVICE.methods_by_name['DeleteAPITokens']._serialized_options = b'\202\323\344\223\002\021*\017/v1/auth/tokens'
  _USERSERVICE.methods_by_name['GetUser']._options = None
  _USERSERVICE.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002\n\022\010/v1/user'
  _USERSERVICE.methods_by_name['UpdateUserDisplayName']._options = None
  _USERSERVICE.methods_by_name['UpdateUserDisplayName']._serialized_options = b'\202\323\344\223\002\032:\001*2\025/v1/user/display_name'
  _USERSERVICE.methods_by_name['UpdateUserEmail']._options = None
  _USERSERVICE.methods_by_name['UpdateUserEmail']._serialized_options = b'\202\323\344\223\002\023:\001*2\016/v1/user/email'
  _USERSERVICE.methods_by_name['GetUserProjects']._options = None
  _USERSERVICE.methods_by_name['GetUserProjects']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/user/{user_id}/projects'
  _USERSERVICE.methods_by_name['GetNotActivatedUsers']._options = None
  _USERSERVICE.methods_by_name['GetNotActivatedUsers']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/user/not_activated'
  _USERSERVICE.methods_by_name['GetAllUsers']._options = None
  _USERSERVICE.methods_by_name['GetAllUsers']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/user/all'
  _EXPIRESAT._serialized_start=186
  _EXPIRESAT._serialized_end=255
  _REGISTERUSERREQUEST._serialized_start=257
  _REGISTERUSERREQUEST._serialized_end=361
  _REGISTERUSERRESPONSE._serialized_start=363
  _REGISTERUSERRESPONSE._serialized_end=410
  _CREATEAPITOKENREQUEST._serialized_start=413
  _CREATEAPITOKENREQUEST._serialized_end=701
  _CREATEAPITOKENRESPONSE._serialized_start=704
  _CREATEAPITOKENRESPONSE._serialized_end=893
  _GETAPITOKENREQUEST._serialized_start=895
  _GETAPITOKENREQUEST._serialized_end=942
  _GETAPITOKENRESPONSE._serialized_start=944
  _GETAPITOKENRESPONSE._serialized_end=1023
  _GETAPITOKENSREQUEST._serialized_start=1025
  _GETAPITOKENSREQUEST._serialized_end=1046
  _GETAPITOKENSRESPONSE._serialized_start=1048
  _GETAPITOKENSRESPONSE._serialized_end=1128
  _DELETEAPITOKENREQUEST._serialized_start=1130
  _DELETEAPITOKENREQUEST._serialized_end=1180
  _DELETEAPITOKENRESPONSE._serialized_start=1182
  _DELETEAPITOKENRESPONSE._serialized_end=1206
  _DELETEAPITOKENSREQUEST._serialized_start=1208
  _DELETEAPITOKENSREQUEST._serialized_end=1257
  _DELETEAPITOKENSRESPONSE._serialized_start=1259
  _DELETEAPITOKENSRESPONSE._serialized_end=1284
  _GETUSERREQUEST._serialized_start=1286
  _GETUSERREQUEST._serialized_end=1327
  _GETUSERRESPONSE._serialized_start=1330
  _GETUSERRESPONSE._serialized_end=1499
  _UPDATEUSERDISPLAYNAMEREQUEST._serialized_start=1501
  _UPDATEUSERDISPLAYNAMEREQUEST._serialized_end=1573
  _UPDATEUSERDISPLAYNAMERESPONSE._serialized_start=1575
  _UPDATEUSERDISPLAYNAMERESPONSE._serialized_end=1661
  _GETUSERPROJECTSREQUEST._serialized_start=1663
  _GETUSERPROJECTSREQUEST._serialized_end=1712
  _USERPROJECT._serialized_start=1714
  _USERPROJECT._serialized_end=1797
  _GETUSERPROJECTSRESPONSE._serialized_start=1799
  _GETUSERPROJECTSRESPONSE._serialized_end=1896
  _ACTIVATEUSERREQUEST._serialized_start=1899
  _ACTIVATEUSERREQUEST._serialized_end=2030
  _ACTIVATEUSERRESPONSE._serialized_start=2032
  _ACTIVATEUSERRESPONSE._serialized_end=2054
  _GETNOTACTIVATEDUSERSREQUEST._serialized_start=2056
  _GETNOTACTIVATEDUSERSREQUEST._serialized_end=2085
  _GETNOTACTIVATEDUSERSRESPONSE._serialized_start=2087
  _GETNOTACTIVATEDUSERSRESPONSE._serialized_end=2174
  _GETALLUSERSREQUEST._serialized_start=2176
  _GETALLUSERSREQUEST._serialized_end=2245
  _USERWITHPERMS._serialized_start=2248
  _USERWITHPERMS._serialized_end=2403
  _GETALLUSERSRESPONSE._serialized_start=2405
  _GETALLUSERSRESPONSE._serialized_end=2512
  _DEACTIVATEUSERREQUEST._serialized_start=2514
  _DEACTIVATEUSERREQUEST._serialized_end=2562
  _DEACTIVATEUSERRESPONSE._serialized_start=2564
  _DEACTIVATEUSERRESPONSE._serialized_end=2588
  _UPDATEUSEREMAILREQUEST._serialized_start=2590
  _UPDATEUSEREMAILREQUEST._serialized_end=2668
  _UPDATEUSEREMAILRESPONSE._serialized_start=2670
  _UPDATEUSEREMAILRESPONSE._serialized_end=2750
  _USERSERVICE._serialized_start=2753
  _USERSERVICE._serialized_end=4977
# @@protoc_insertion_point(module_scope)
